# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

# Find the curve node for an effect
def get_curve_node(item, fx, type = 'EASING'):
    curve, ng = (None, None)
    container = item.get('geo_node_container')
    if container is None:
        return None
    mod = container.modifiers.get('ANIMAX')
    if mod is None:
        return None
    fx_node = mod.node_group.nodes.get(fx.name)
    if fx_node is None:
        return None
    if type == 'EASING':
        curve = fx_node.node_tree.nodes.get('Easing_Curve')
    elif type == 'ROTATION':
        curve = fx_node.node_tree.nodes.get('Rotation_Curve')
    return curve


# Transform effect properties UI
def transform_fx_ui(layout,item, effect, panel):
    if panel == 'LOC':
        col = layout.column()
        col.prop(effect, 'explode_location', icon = 'MOD_EXPLODE')
        if not effect.explode_location:
            col.prop(effect, 'replace_location', icon = 'BLANK1')
        row = layout.row(align=True)
        col = row.column()
        col.prop(effect, 'location', text = 'Location')
        col2 = row.column()
        col2.scale_x = 0.8
        col2.prop(effect, 'random_location', text = 'Randomize')
        col = layout.column()
        col.prop(effect, 'random_location_seed')
        
    if panel == 'ROT':
        col = layout.column()
        col.prop(effect, 'replace_rotation', icon = 'BLANK1')
        row = layout.row(align=True)
        col = row.column()
        col.prop(effect, 'rotation', text = 'Rotation')
        col2 = row.column()
        col2.scale_x = 0.8
        col2.prop(effect, 'random_rotation', text = 'Randomize')
        col = layout.column()
        col.prop(effect, 'random_rotation_seed')
        
    if panel == 'SCALE':
        col = layout.column(align = True)
        col.prop(effect, 'scale_fade_out', icon = 'BLANK1')
        if effect.scale_fade_out:
            col.prop(effect, 'fade_out_smooth_step', slider = True)
        col = layout.column()
        col.prop(effect, 'replace_scale', icon = 'BLANK1')
        col.prop(effect, 'uniform_scale', icon = 'BLANK1')
        row = layout.row(align=True)
        col = row.column()
        if effect.uniform_scale:
            col.prop(effect, 'uniform_scale_value', text = 'Scale')
            col2 = row.column()
            col2.scale_x = 0.8
            col2.prop(effect, 'uniform_random_scale', text = 'Randomize')
        else:
            col.prop(effect, 'scale', text = 'Scale')
            col2 = row.column()
            col2.scale_x = 0.8
            col2.prop(effect, 'random_scale', text = 'Randomize')
        col = layout.column()
        col.prop(effect, 'random_scale_seed')
    
    if panel == 'EXTRA':
        col = layout.column()
        col.label(text = 'No Extra Options', icon = 'INFO')
    
# Noise effect properties UI
def noise_fx_ui(layout, item, effect, panel):
    if panel == 'LOC':
        col = layout.column()
        col.prop(effect, 'location', text = '')
        
    if panel == 'ROT':
        col = layout.column()
        col.prop(effect, 'rotation', text = '')
        layout.prop(effect, 'align_rotation', icon = 'BLANK1', text = 'Align To Trajectory')
        if effect.align_rotation:
            col = layout.column(align = True)
            row = col.row()
            row.prop(effect, 'axis_enum', expand = True)
            #col.prop(effect, 'invert_axis', icon = 'BLANK1')
            curve_node = get_curve_node(item, effect, 'ROTATION')
            layout.template_curve_mapping(curve_node, "mapping")
    
    if panel == 'SCALE':
        col = layout.column(align = True)
        col.prop(effect, 'scale_fade_out', icon = 'BLANK1')
        if effect.scale_fade_out:
            col.prop(effect, 'fade_out_smooth_step', slider = True)
        col = layout.column()
        col.prop(effect, 'uniform_scale', icon = 'BLANK1')
        if effect.uniform_scale:
            col.prop(effect, 'uniform_scale_value', text = 'Scale')
        else:
            col.prop(effect, 'scale', text = 'Scale')
            
    if panel == 'EXTRA':
        col = layout.column()
        col.prop(effect, 'continuous_animation', icon = 'BLANK1')
        col.prop(effect, 'noise_frequency')
        col.prop(effect, 'noise_scale')
        col.prop(effect, 'noise_detail')
        col.prop(effect, 'noise_roughness')
        col.prop(effect, 'noise_distortion')
        col.prop(effect, 'random_seed')
    
# Follow Curve effect properties UI
def follow_curve_fx_ui(layout, item, effect, panel):
    if panel == 'LOC':
        col = layout.column()
        col.prop(effect, 'follow_object')
        col.prop(effect, 'follow_reverse_curve', icon = 'BLANK1')
        col.prop(effect, 'follow_world_position', icon = 'BLANK1')
        col.prop(effect, 'num_turns')
        
    if panel == 'ROT':
        layout.prop(effect, 'align_rotation', icon = 'BLANK1')
        if effect.align_rotation:
            col = layout.column(align = True)
            row = col.row()
            row.prop(effect, 'axis_enum', expand = True)
            col.prop(effect, 'invert_axis', icon = 'BLANK1')
            curve_node = get_curve_node(item, effect, 'ROTATION')
            layout.template_curve_mapping(curve_node, "mapping")
        
    if panel == 'SCALE':
        col = layout.column(align = True)
        col.prop(effect, 'scale_fade_out', icon = 'BLANK1')
        if effect.scale_fade_out:
            col.prop(effect, 'fade_out_smooth_step', slider = True)
    
    if panel == 'EXTRA':
        col = layout.column()
        col.prop(effect, 'follow_resolution')
        
        
# Attract effect properties UI
def attract_fx_ui(layout, item, effect, panel):
    if panel == 'LOC':
        col = layout.column()
        col.prop(effect, 'attractor')
        col.prop(effect, 'factor', slider = True)
        if effect.factor > 0:
            col.prop(effect, 'collapse_axis')
        
    if panel == 'ROT':
        layout.prop(effect, 'align_rotation', icon = 'BLANK1', text = 'Align To Trajectory')
        if effect.align_rotation:
            col = layout.column(align = True)
            row = col.row()
            row.prop(effect, 'axis_enum', expand = True)
            col.prop(effect, 'invert_axis', icon = 'BLANK1')
            curve_node = get_curve_node(item, effect, 'ROTATION')
            layout.template_curve_mapping(curve_node, "mapping")
        
    if panel == 'SCALE':
        col = layout.column(align = True)
        col.prop(effect, 'scale_fade_out', icon = 'BLANK1')
        if effect.scale_fade_out:
            col.prop(effect, 'fade_out_smooth_step', slider = True)
    
    if panel == 'EXTRA':
        col = layout.column()
        col.label(text = 'No Extra Options', icon = 'INFO')
        
# Explode effect properties UI
def explode_fx_ui(layout, item, effect, panel):
    if panel == 'LOC':
        row = layout.row(align=True)
        col = row.column()
        col.prop(effect, 'velocity')
        col2 = row.column()
        col2.scale_x = 0.8
        col2.prop(effect, 'random_location', text = 'Randomize')
        col = layout.column()
        col.prop(effect, 'gravity')
        col.prop(effect, 'random_location_seed')
        
    if panel == 'ROT':
        col = layout.column()
        col.label(text = 'No Rotation', icon = 'INFO')
    
    if panel == 'SCALE':
        col = layout.column(align = True)
        col.prop(effect, 'scale_fade_out', icon = 'BLANK1')
        if effect.scale_fade_out:
            col.prop(effect, 'fade_out_smooth_step', slider = True)
    
    if panel == 'EXTRA':
        col = layout.column()
        col.prop(effect, 'time_multiplier')
    
# Repulse effect properties UI
def repulse_fx_ui(layout, item, effect, panel):
    if panel == 'LOC':
        col = layout.column()
        col.prop(effect, 'distance')
    
    if panel == 'ROT':
        col = layout.column()
        col.label(text = 'No Rotation', icon = 'INFO')
    
    if panel == 'SCALE':
        col = layout.column(align = True)
        col.prop(effect, 'scale_fade_out', icon = 'BLANK1')
        if effect.scale_fade_out:
            col.prop(effect, 'fade_out_smooth_step', slider = True)
    
    if panel == 'EXTRA':
        col = layout.column()
        row = col.row()
        row.prop(effect, "repulse_method", expand = True)
        col.prop(effect, 'repulsor')
        col.prop(effect, 'force')
        
    
# Project effect properties UI
def project_fx_ui(layout, item, effect, panel):
    if panel == 'LOC':
        col = layout.column()
        col.prop(effect, 'factor', slider = True)
        
    if panel == 'ROT':
        layout.prop(effect, 'align_rotation', icon = 'BLANK1', text = 'Align To Normals')
        if effect.align_rotation:
            col = layout.column(align = True)
            row = col.row()
            row.prop(effect, 'axis_enum', expand = True)
            #col.prop(effect, 'invert_axis', icon = 'BLANK1')
            curve_node = get_curve_node(item, effect, 'ROTATION')
            layout.template_curve_mapping(curve_node, "mapping")
    
    if panel == 'SCALE':
        col = layout.column(align = True)
        col.prop(effect, 'scale_fade_out', icon = 'BLANK1')
        if effect.scale_fade_out:
            col.prop(effect, 'fade_out_smooth_step', slider = True)
        col = layout.column()
        col.prop(effect, 'fade_out_missed', icon = 'BLANK1')
    
    if panel == 'EXTRA':
        col = layout.column(align = True)
        row = col.row()
        row.prop(effect, "col_ob_switch", expand = True)
        prop = 'target_ob' if effect.col_ob_switch == '0' else 'target_col'
        col.prop(effect, prop)
        col = layout.column()
        col.prop(effect, 'ray_direction')
        col.prop(effect, 'ray_length')
    
# Collapse effect properties UI
def collapse_fx_ui(layout, item, effect, panel):
    if panel == 'LOC':
        col = layout.column()
        col.prop(effect, 'collapse_axis')
        col.prop(effect, 'collapse_offset')
        col.prop(effect, 'collapse_rotation', text = 'Angle')
    
    if panel == 'ROT':
        col = layout.column()
        col.label(text = 'No Rotation', icon = 'INFO')
    
    if panel == 'SCALE':
        col = layout.column(align = True)
        col.prop(effect, 'scale_fade_out', icon = 'BLANK1')
        if effect.scale_fade_out:
            col.prop(effect, 'fade_out_smooth_step', slider = True)
            
    if panel == 'EXTRA':
        col = layout.column()
        col.label(text = 'No Extra Options', icon = 'INFO')
    
# Orbit effect properties UI
def orbit_fx_ui(layout, item, effect, panel):
    if panel == 'LOC':
        col = layout.column()
        col.prop(effect, 'center_ob')
        col.prop(effect, 'rotation', text = 'Angle')
    
    if panel == 'ROT':
        col = layout.column()
        col.label(text = 'No Rotation', icon = 'INFO')
    
    if panel == 'SCALE':
        col = layout.column(align = True)
        col.prop(effect, 'scale_fade_out', icon = 'BLANK1')
        if effect.scale_fade_out:
            col.prop(effect, 'fade_out_smooth_step', slider = True)
    
    if panel == 'EXTRA':
        col = layout.column()
        col.label(text = 'No Extra Options', icon = 'INFO')
    
# Wave effect properties UI
def wave_fx_ui(layout, item, effect, panel):
    if panel == 'LOC':
        col = layout.column()
        col.prop(effect, 'location', text = '')
        
    if panel == 'ROT':
        col = layout.column()
        col.prop(effect, 'rotation', text = '')
    
    if panel == 'SCALE':
        col = layout.column(align = True)
        col.prop(effect, 'scale_fade_out', icon = 'BLANK1')
        if effect.scale_fade_out:
            col.prop(effect, 'fade_out_smooth_step', slider = True)
        col = layout.column()
        col.prop(effect, 'scale', text = '')
    
    if panel == 'EXTRA':
        col = layout.column()
        col.prop(effect, 'continuous_animation', icon = 'BLANK1')
        col.prop(effect, 'coord_rotation')
        col.prop(effect, 'noise_frequency')
        col.prop(effect, 'noise_scale')
        col.prop(effect, 'noise_detail')
        col.prop(effect, 'details_scale')
        col.prop(effect, 'noise_roughness')
        col.prop(effect, 'noise_distortion')
        col.prop(effect, 'wave_phase')
    
# Robotic effect properties UI
def robotic_fx_ui(layout, item, effect, panel):
    if panel == 'LOC':
        col = layout.column()
        col.prop(effect, 'distance_vec', text = '')
        
    if panel == 'ROT':
        col = layout.column()
        col.prop(effect, 'rotation', text = '')
    
    if panel == 'SCALE':
        col = layout.column(align = True)
        col.prop(effect, 'scale_fade_out', icon = 'BLANK1')
        if effect.scale_fade_out:
            col.prop(effect, 'fade_out_smooth_step', slider = True)
    
    if panel == 'EXTRA':
        col = layout.column()
        col.prop(effect, 'random_seed', text = 'Random Seed')
        
# Empty effect properties UI
def empty_fx_ui(layout, item, effect, panel):
    if panel == 'LOC':
        col = layout.column()
        col.label(text = 'No Location', icon = 'INFO')
        
    if panel == 'ROT':
        col = layout.column()
        col.label(text = 'No Rotation', icon = 'INFO')
    
    if panel == 'SCALE':
        col = layout.column(align = True)
        col.prop(effect, 'scale_fade_out', icon = 'BLANK1')
        if effect.scale_fade_out:
            col.prop(effect, 'fade_out_smooth_step', slider = True)
    
    if panel == 'EXTRA':
        col = layout.column()
        col.label(text = 'No Extra Options', icon = 'INFO')