# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

# Collection Item UI
def coll_item_ui(layout, item, ng):
    col = layout.column()
    if ng is None:
        col.alert = True
        col.label(text = 'The node group not found', icon = 'ERROR')
        return
    
    row = col.row(align=True)
    row.prop(item, 'collection', text = '', icon = 'OUTLINER_COLLECTION')
    row.operator("animax.copy_name", text = '', icon = 'COPYDOWN')
    
    col = layout.column(align=True)
    col.prop(item, 'control_time', icon = 'PREVIEW_RANGE')
    if item.control_time:
        col.prop(item, 'frame')
    col = layout.column()
    col.prop(item, 'realize_instances', icon = 'BLANK1')
    
    coll_node = ng.nodes.get('ANIMAX_Collection')
    if coll_node is None:
        layout.label(text = 'Collection Node Missing!', icon = 'ERROR')
        return
    
    set_material_node = ng.nodes.get('ANIMAX_Set_Material_NG')
    if set_material_node is None:
        layout.label(text = 'Set Material Node Missing!', icon = 'ERROR')
    else:
        col.prop(set_material_node.inputs[2], 'default_value', text = '')
    
    box = layout.box()
    box.label(text = 'Use Local Transform')
    row = box.row(align=True)
    row.prop(item, 'use_local_location', text = 'Loc', icon = 'BLANK1')
    row.prop(item, 'use_local_rotation', text = 'Rot', icon = 'BLANK1')
    row.prop(item, 'use_local_scale', text = 'Scale', icon = 'BLANK1')
    
# Text Item UI
def text_item_ui(layout, item, ng):
    col = layout.column()
    if ng is None:
        col.alert = True
        col.label(text = 'The node group not found', icon = 'ERROR')
        return
    
    col = layout.column(align=True)
    col.prop(item, 'control_time', icon = 'PREVIEW_RANGE')
    if item.control_time:
        col.prop(item, 'frame')
    col = layout.column()
    col.prop(item, 'realize_instances', icon = 'BLANK1')
    
    box = layout.box()
    box.label(text = 'Use Local Transform')
    row = box.row(align=True)
    row.prop(item, 'use_local_location', text = 'Loc', icon = 'BLANK1')
    row.prop(item, 'use_local_rotation', text = 'Rot', icon = 'BLANK1')
    row.prop(item, 'use_local_scale', text = 'Scale', icon = 'BLANK1')
    
    text_node = ng.nodes.get('ANIMAX_Text')
    if text_node is None:
        layout.label(text = 'Text Node Missing!', icon = 'ERROR')
        return
    
    col.prop(text_node.inputs[0], 'default_value', text = '', icon = 'FONT_DATA')
    
    set_material_node = ng.nodes.get('ANIMAX_Set_Material_NG')
    if set_material_node is None:
        layout.label(text = 'Set Material Node Missing!', icon = 'ERROR')
    else:
        col.prop(set_material_node.inputs[2], 'default_value', text = '')
    
    row = col.row(align=True)
    row.prop(text_node, 'font', text = '')
    row.operator("animax.load_font", text = '', icon = 'FILEBROWSER')
    
    col.prop(text_node.inputs[1], 'default_value', text = 'Size')
    col.prop(text_node.inputs[2], 'default_value', text = 'Character Spacing')
    col.prop(text_node.inputs[3], 'default_value', text = 'Word Spacing')
    col.prop(text_node.inputs[4], 'default_value', text = 'Line Spacing')
    col.prop(text_node.inputs[5], 'default_value', text = 'Max Width')
    
    extrude_node = ng.nodes.get('ANIMAX_Extrude_NG')
    if extrude_node is None:
        layout.label(text = 'Extrude Node Missing!', icon = 'ERROR')
    else:
        col.prop(extrude_node.inputs[1], 'default_value', text = 'Extrude')
        if hasattr(item, 'merge_by_distance') and extrude_node.inputs[1].default_value != 0.0:
            col.prop(item, 'merge_by_distance', icon = 'BLANK1')
    col.prop(text_node, 'overflow')
    col.prop(text_node, 'align_x')
    col.prop(text_node, 'align_y')
    col.prop(text_node, 'pivot_mode')
    
# Custom NG Item UI
def custom_ng_item_ui(layout, item, ng):
    col = layout.column()
    if ng is None:
        col.alert = True
        col.label(text = 'The node group not found', icon = 'ERROR')
        return
    
    row = col.row(align=True)
    row.prop(item, 'custom_ng', text = '')
    row.operator("animax.copy_name", text = '', icon = 'COPYDOWN')
    
    col = layout.column(align=True)
    col.prop(item, 'control_time', icon = 'PREVIEW_RANGE')
    if item.control_time:
        col.prop(item, 'frame')
    col = layout.column()
    col.prop(item, 'realize_instances', icon = 'BLANK1')
    
    set_material_node = ng.nodes.get('ANIMAX_Set_Material_NG')
    if set_material_node is None:
        layout.label(text = 'Set Material Node Missing!', icon = 'ERROR')
    else:
        col.prop(set_material_node.inputs[2], 'default_value', text = '')
    
    box = layout.box()
    box.label(text = 'Use Local Transform')
    row = box.row(align=True)
    row.prop(item, 'use_local_location', text = 'Loc', icon = 'BLANK1')
    row.prop(item, 'use_local_rotation', text = 'Rot', icon = 'BLANK1')
    row.prop(item, 'use_local_scale', text = 'Scale', icon = 'BLANK1')
    
    custom_ng_node = ng.nodes.get('ANIMAX_Custom_NG')
    if custom_ng_node is None:
        layout.label(text = 'Custom NG Node Missing!', icon = 'ERROR')
        return
    
    if item.custom_ng is None:
        return
    #col.prop(custom_ng_node, 'node_tree', text = '')
    if not len(custom_ng_node.inputs):
        return
    box = layout.box()
    box.label(text = 'Node Group Inputs')
    for i in custom_ng_node.inputs:
        try:
            if hasattr(i, 'default_value'):
                box.prop(i, 'default_value', text = i.name)
        except:
            box.label(text = 'Error', icon = 'ERROR')
            
        
    
